@@ -157,6 +157,9 @@ def push_to_repo(args: Dict[str, Any]) -> None:
     column_name = args["COLUMN"]
     repo = gh.get_repo(repo_name)
     username = github_username(gh)
+    assignees = args["--assign-to"] or (
+        [username] if not args["--no-self-assign"] else []
+    )
 
     # Get all labels
     labels = repo.get_labels()
@@ -234,17 +237,49 @@ def push_to_repo(args: Dict[str, Any]) -> None:
         print(dye(f"Error: column {column_name!r} does not exist!", fg=0xF00))
         return
 
+    # Milestone
+    milestone = None
+    if args["--milestone"]:
+        for m in repo.get_milestones():
+            if m.title.lower() == args["--milestone"].lower():
+                milestone = m
+                break
+        if milestone is None and args["--create-missing"]:
+            if ask(
+                q.Confirm(
+                    "ans", message=f"Create missing milestone {args['--milestone']!r}?"
+                )
+            ):
+                # TODO: Ask for a due date
+                milestone = repo.create_milestone(title=args["--milestone"])
+            else:
+                return
+        elif milestone is None:
+            print(
+                dye(
+                    f"Error: milestone {args['--milestone']!r} does not exit!", fg=0xF00
+                )
+            )
+            return
+
     owner, repository = repo_name.split("/")
 
     if args["--issue"]:
-        issue = repo.create_issue(
+        # Cant just use milestone=milestone because
+        # create_issue(milestone=None) does not work, linter says.
+        issue_creation_args = dict(
             title=args["--title"] or idea,
             body=idea if args["--title"] else "",
-            assignees=[username],
+            assignees=assignees,
             labels=args["--tag"],
         )
+        if milestone is not None:
+            issue = repo.create_issue(**issue_creation_args, milestone=milestone)
+        else:
+            issue = repo.create_issue(**issue_creation_args)
+
         card = column.create_card(content_id=issue.id, content_type="Issue")
-        url = issue.html_url if args["--title"] else project.html_url
+        url = issue.html_url
 
         print(
             make_github_issue_art(
@@ -258,6 +293,8 @@ def push_to_repo(args: Dict[str, Any]) -> None:
                 labels=args["--tag"],
                 body=issue.body,
                 title=issue.title,
+                assignees=assignees,
+                milestone=(milestone.title if milestone is not None else None),
             )
         )
 
@@ -290,7 +327,7 @@ def push_to_user(args: Dict[str, Any]) -> None:
     column_name: str = args["PROJECT"]
     username = github_username(gh)
     print(
-        f"Saving card in {dye(github_username(gh), C_PRIMARY)} › {dye(project_name, C_PRIMARY)} › {dye(column_name, C_PRIMARY)}..."
+        f"Saving card in {dye(username, C_PRIMARY)} › {dye(project_name, C_PRIMARY)} › {dye(column_name, C_PRIMARY)}..."
     )
     project = None
     user = gh.get_user(github_username(gh))
